/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.games.model;

import com.google.api.client.json.GenericJson;

/**
 * This is a JSON template for a room creation request.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Play Game Services API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class RoomCreateRequest extends GenericJson {

  /**
   * Criteria for auto-matching players into this room.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private RoomAutoMatchingCriteria autoMatchingCriteria;

  /**
   * The capabilities that this client supports for realtime communication.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> capabilities;

  /**
   * Client address for the player creating the room.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private RoomClientAddress clientAddress;

  /**
   * The player IDs to invite to the room.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> invitedPlayerIds;

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string
   * games#roomCreateRequest.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Network diagnostics for the client creating the room.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private NetworkDiagnostics networkDiagnostics;

  /**
   * The variant / mode of the application to be played. This can be any integer value, or left
   * blank. You should use a small number of variants to keep the auto-matching pool as large as
   * possible.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer variant;

  /**
   * Criteria for auto-matching players into this room.
   * The value returned may be {@code null}.
   */
  public RoomAutoMatchingCriteria getAutoMatchingCriteria() {
    return autoMatchingCriteria;
  }

  /**
   * Criteria for auto-matching players into this room.
   * The value set may be {@code null}.
   */
  public RoomCreateRequest setAutoMatchingCriteria(RoomAutoMatchingCriteria autoMatchingCriteria) {
    this.autoMatchingCriteria = autoMatchingCriteria;
    return this;
  }

  /**
   * The capabilities that this client supports for realtime communication.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getCapabilities() {
    return capabilities;
  }

  /**
   * The capabilities that this client supports for realtime communication.
   * The value set may be {@code null}.
   */
  public RoomCreateRequest setCapabilities(java.util.List<String> capabilities) {
    this.capabilities = capabilities;
    return this;
  }

  /**
   * Client address for the player creating the room.
   * The value returned may be {@code null}.
   */
  public RoomClientAddress getClientAddress() {
    return clientAddress;
  }

  /**
   * Client address for the player creating the room.
   * The value set may be {@code null}.
   */
  public RoomCreateRequest setClientAddress(RoomClientAddress clientAddress) {
    this.clientAddress = clientAddress;
    return this;
  }

  /**
   * The player IDs to invite to the room.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getInvitedPlayerIds() {
    return invitedPlayerIds;
  }

  /**
   * The player IDs to invite to the room.
   * The value set may be {@code null}.
   */
  public RoomCreateRequest setInvitedPlayerIds(java.util.List<String> invitedPlayerIds) {
    this.invitedPlayerIds = invitedPlayerIds;
    return this;
  }

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string
   * games#roomCreateRequest.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string
   * games#roomCreateRequest.
   * The value set may be {@code null}.
   */
  public RoomCreateRequest setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Network diagnostics for the client creating the room.
   * The value returned may be {@code null}.
   */
  public NetworkDiagnostics getNetworkDiagnostics() {
    return networkDiagnostics;
  }

  /**
   * Network diagnostics for the client creating the room.
   * The value set may be {@code null}.
   */
  public RoomCreateRequest setNetworkDiagnostics(NetworkDiagnostics networkDiagnostics) {
    this.networkDiagnostics = networkDiagnostics;
    return this;
  }

  /**
   * The variant / mode of the application to be played. This can be any integer value, or left
   * blank. You should use a small number of variants to keep the auto-matching pool as large as
   * possible.
   * The value returned may be {@code null}.
   */
  public Integer getVariant() {
    return variant;
  }

  /**
   * The variant / mode of the application to be played. This can be any integer value, or left
   * blank. You should use a small number of variants to keep the auto-matching pool as large as
   * possible.
   * The value set may be {@code null}.
   */
  public RoomCreateRequest setVariant(Integer variant) {
    this.variant = variant;
    return this;
  }

}
