/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.games.model;

import com.google.api.client.json.GenericJson;

/**
 * This is a JSON template for an update on the status of a peer in a room.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Play Game Services API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class RoomP2PStatus extends GenericJson {

  /**
   * The amount of time in milliseconds it took to establish connections with this peer.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer connectionSetupLatencyMillis;

  /**
   * The error code in event of a failure. Possible values are:   - "P2P_FAILED" - The client failed
   * to establish a P2P connection with the peer.  - "PRESENCE_FAILED" - The client failed to
   * register to receive P2P connections.  - "RELAY_SERVER_FAILED" - The client received an error
   * when trying to use the relay server to establish a P2P connection with the peer.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String error;

  /**
   * More detailed diagnostic message returned in event of a failure.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key("error_reason")
  private String errorReason;

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string
   * games#roomP2PStatus.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The ID of the participant.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String participantId;

  /**
   * The status of the peer in the room. Possible values are:   - "CONNECTION_ESTABLISHED" - The
   * client established a P2P connection with the peer.  - "CONNECTION_FAILED" - The client failed
   * to establish directed presence with the peer.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String status;

  /**
   * The amount of time in milliseconds it took to send packets back and forth on the unreliable
   * channel with this peer.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer unreliableRoundtripLatencyMillis;

  /**
   * The amount of time in milliseconds it took to establish connections with this peer.
   * The value returned may be {@code null}.
   */
  public Integer getConnectionSetupLatencyMillis() {
    return connectionSetupLatencyMillis;
  }

  /**
   * The amount of time in milliseconds it took to establish connections with this peer.
   * The value set may be {@code null}.
   */
  public RoomP2PStatus setConnectionSetupLatencyMillis(Integer connectionSetupLatencyMillis) {
    this.connectionSetupLatencyMillis = connectionSetupLatencyMillis;
    return this;
  }

  /**
   * The error code in event of a failure. Possible values are:   - "P2P_FAILED" - The client failed
   * to establish a P2P connection with the peer.  - "PRESENCE_FAILED" - The client failed to
   * register to receive P2P connections.  - "RELAY_SERVER_FAILED" - The client received an error
   * when trying to use the relay server to establish a P2P connection with the peer.
   * The value returned may be {@code null}.
   */
  public String getError() {
    return error;
  }

  /**
   * The error code in event of a failure. Possible values are:   - "P2P_FAILED" - The client failed
   * to establish a P2P connection with the peer.  - "PRESENCE_FAILED" - The client failed to
   * register to receive P2P connections.  - "RELAY_SERVER_FAILED" - The client received an error
   * when trying to use the relay server to establish a P2P connection with the peer.
   * The value set may be {@code null}.
   */
  public RoomP2PStatus setError(String error) {
    this.error = error;
    return this;
  }

  /**
   * More detailed diagnostic message returned in event of a failure.
   * The value returned may be {@code null}.
   */
  public String getErrorReason() {
    return errorReason;
  }

  /**
   * More detailed diagnostic message returned in event of a failure.
   * The value set may be {@code null}.
   */
  public RoomP2PStatus setErrorReason(String errorReason) {
    this.errorReason = errorReason;
    return this;
  }

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string
   * games#roomP2PStatus.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string
   * games#roomP2PStatus.
   * The value set may be {@code null}.
   */
  public RoomP2PStatus setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The ID of the participant.
   * The value returned may be {@code null}.
   */
  public String getParticipantId() {
    return participantId;
  }

  /**
   * The ID of the participant.
   * The value set may be {@code null}.
   */
  public RoomP2PStatus setParticipantId(String participantId) {
    this.participantId = participantId;
    return this;
  }

  /**
   * The status of the peer in the room. Possible values are:   - "CONNECTION_ESTABLISHED" - The
   * client established a P2P connection with the peer.  - "CONNECTION_FAILED" - The client failed
   * to establish directed presence with the peer.
   * The value returned may be {@code null}.
   */
  public String getStatus() {
    return status;
  }

  /**
   * The status of the peer in the room. Possible values are:   - "CONNECTION_ESTABLISHED" - The
   * client established a P2P connection with the peer.  - "CONNECTION_FAILED" - The client failed
   * to establish directed presence with the peer.
   * The value set may be {@code null}.
   */
  public RoomP2PStatus setStatus(String status) {
    this.status = status;
    return this;
  }

  /**
   * The amount of time in milliseconds it took to send packets back and forth on the unreliable
   * channel with this peer.
   * The value returned may be {@code null}.
   */
  public Integer getUnreliableRoundtripLatencyMillis() {
    return unreliableRoundtripLatencyMillis;
  }

  /**
   * The amount of time in milliseconds it took to send packets back and forth on the unreliable
   * channel with this peer.
   * The value set may be {@code null}.
   */
  public RoomP2PStatus setUnreliableRoundtripLatencyMillis(Integer unreliableRoundtripLatencyMillis) {
    this.unreliableRoundtripLatencyMillis = unreliableRoundtripLatencyMillis;
    return this;
  }

}
